#
# spec file for package python-oslo.utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.utils
Version:        6.3.0
Release:        1.2
Summary:        OpenStack Utils Library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.utils
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.utils/oslo.utils-6.3.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-Babel
BuildRequires:  python3-ddt
BuildRequires:  python3-debtcollector >= 1.2.0
BuildRequires:  python3-eventlet
BuildRequires:  python3-fixtures
BuildRequires:  python3-iso8601 >= 0.1.11
BuildRequires:  python3-monotonic
BuildRequires:  python3-netaddr >= 0.7.18
BuildRequires:  python3-netifaces >= 0.10.4
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-pyparsing >= 2.1.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
The oslo.utils library provides support for common utility type functions,
such as encoding, exception handling, string manipulation, and time handling.

%package -n python3-oslo.utils
Summary:        OpenStack Utils Library
Requires:       python3-debtcollector >= 1.2.0
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-netaddr >= 0.7.18
Requires:       python3-netifaces >= 0.10.4
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-pyparsing >= 2.1.0
Requires:       python3-pytz >= 2013.6

%description -n python3-oslo.utils
The oslo.utils library provides support for common utility type functions,
such as encoding, exception handling, string manipulation, and time handling.

This package contains the Python 3.x module.

%package -n python-oslo.utils-doc
Summary:        Documentation for OpenStack utils library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.utils-doc
Documentation for OpenStack utils library.

%prep
%autosetup -p1 -n oslo.utils-6.3.0

%py_req_cleanup

%build
%py3_build

%install
%py3_install

# generate html docs
PBR_VERSION=6.3.0 %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%check
# tests fail with python 3.8
rm -v oslo_utils/tests/test_reflection.py
%{openstack_stestr_run}

%files -n python3-oslo.utils
%license LICENSE
%doc ChangeLog README.rst
%{python3_sitelib}/oslo_utils
%{python3_sitelib}/*.egg-info

%files -n python-oslo.utils-doc
%doc doc/build/html
%license LICENSE

%changelog
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 6.3.0
  - Mask chapsecret
  - Update master for stable/2023.2
  - versionutil: Remove trailing alpha/beta/rc suffix
  - Imported Translations from Zanata
  - Fix missing PyYAML dependency
* Fri Dec  1 2023 cloud-devel@suse.de
- update to version 6.2.1
  - Imported Translations from Zanata
* Tue Jul 18 2023 cloud-devel@suse.de
- update to version 6.2.0
  - Replace deprecated assertAlmostEquals method
  - Fix compatibility with Python 3.8
  - Moves supported python runtimes from version 3.8 to 3.10
  - Bump bandit
  - strutils: update string_to_bytes
  - Implement zoneinfo support to drop dependency to pytz
  - Add netutils.get_my_ipv6()
  - Use the new openstack-python3-jobs template
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Update units for current SI prefixes
  - Update master for stable/2023.1
* Thu Dec  1 2022 cloud-devel@suse.de
- update to version 6.1.0
  - [imageutils] Fix __str__ for QemuImgInfo
  - Update master for stable/zed
  - Imported Translations from Zanata
  - Add Python3 antelope unit tests
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 6.0.1
  - Imported Translations from Zanata
* Thu Aug 11 2022 cloud-devel@suse.de
- update to version 6.0.0
  - requirements: Remove explicit pbr dependency
  - Remove deprecated helpers from oslo_utils.timeutils
  - Remove unnecessary unicode prefixes
  - Remove oslo_utils.fnmatch
  - bindep: Use Python 3 devel packages
  - strutils: Defer import of pyparsing
  - Drop python3.6/3.7 support in testing runtime
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove mock dependency
* Tue May 10 2022 cloud-devel@suse.de
- update to version 4.13.0
  - Add backing file format to the output
  - Fix formatting of release list
  - Update master for stable/yoga
  - Update python testing classifier
  - Update master for stable/xena
  - Fix regex used to mask password
  - QemuImgInfo: Fix inconsistent value format of encrypted
  - Add Python3 zed unit tests
  - Add Python3 yoga unit tests
  - setup.cfg: Replace dashes with underscores
  - fix strutils password regex
  - Use LOG.warning instead of deprecated LOG.warn
  - Changed minversion in tox to 3.18.0
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 4.10.0
  - Switch to collections.abc.*
  - Deprecate the fnmatch module.
  - Ussuri+ is python3 only and update python to python3
  - Remove references to 'sys.version_info'
  - Dropping lower constraints testing
  - QemuImgInfo: Skip deprecation warning when output is not passed
  - Deprecate the human format on QemuImgInfo
  - Add Python3 xena unit tests
  - Move flake8 as a pre-commit local target.
  - Drop lower-constraints
  - Drop warnings enable filter
  - Update master for stable/wallaby
  - Address nits from six removal patch
  - Modify UUID sentinel to support keystone-like UUIDs
  - strutils: Stop masking encryption_key_id
* Sun May  2 2021 cloud-devel@suse.de
- update to version 4.8.0
  - Add a ``strict`` flag allowing users to restrict validation of IPv4 format
  - Use py3 as the default runtime for tox
  - Update master for stable/victoria
  - Add function to encapsule md5 for FIPS systems
  - Use TOX_CONSTRAINTS_FILE
  - Add Python3 wallaby unit tests
  - Remove all usage of six library
  - Dropping lower constraints testing
  - Adding pre-commit
  - Add Python3 victoria unit tests
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.6.0
  - Remove monotonic usage
  - Fix is_same_callback() testing for python3.8
  - Switch to newer openstackdocstheme and reno versions
  - Fix hacking min version to 3.0.1
  - versionutils: switch from pkg_resources to packaging
  - Fix uuidsentinel to follow getattr protocol
  - Add util methods for checking json and yaml formatted file
  - Align contributing doc with oslo's policy
  - Remove the unused coding style modules
  - Remove translation sections from setup.cfg
  - Imported Translations from Zanata
  - Add release notes links to doc index
  - Bump bandit version
  - Fix pygments style
  - Release greenthread when computing checksum
  - Update master for stable/ussuri
  - Stop to use the __future__ module.
  - New method in netutils: get_mac_addr_by_ipv6
  - [goal] Migrate testing to ubuntu focal
* Mon Aug 10 2020 cloud-devel@suse.de
- update to version 4.1.2
  - Update .gitreview for stable/ussuri
  - Release greenthread when computing checksum
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.1.1
  - trivial: Move setup code into setUp helper
  - Switch to Ussuri jobs
  - Remove universal wheel configuration
  - tests: Convert remaining tests to mock
  - tox: Use upper-constraints for docs jobs
  - Make mask_password case insensitive, and add new patterns
  - Ignore releasenote cache within git untracked files
  - Ignore the .eggs directory
  - Support "qemu-img info" virtual size in QEMU 4.1 and later
  - reword releasenote for py27 support dropping
  - Bump the openstackdocstheme extension to 1.20
  - tox: Keeping going with docs
  - Update master for stable/train
  - Add test to check scientific notation on disk virtual size
  - Update hacking for Python3
  - Use unittest.mock instead of third party mock
  - remove outdated header
  - Fix invalid escapes in regular expression strings
  - tox: Trivial cleanup
  - imageutils: Report format specific details when using JSON output format
  - Verify the sanitize keys are lowered
  - Update the constraints url
  - Make mask_dict_password case insensitive and add new patterns
  - Fix regex to correctly recognize scientific notation with QemuImgInfo
  - Flatten test case
  - [ussuri][goal] Drop python 2.7 support and testing
* Wed Mar 18 2020 cloud-devel@suse.de
- update to version 3.41.5
  - Fix regex to correctly recognize scientific notation with QemuImgInfo
* Tue Mar 17 2020 cloud-devel@suse.de
- update to version 3.41.4
  - Update .gitreview for stable/train
  - Support "qemu-img info" virtual size in QEMU 4.1 and later
  - Make mask_password case insensitive, and add new patterns
  - Verify the sanitize keys are lowered
  - Make mask_dict_password case insensitive and add new patterns
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/train
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.41.1
  - Add Python 3 Train unit tests
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - Add digestmod when using hmac
  - Dropping the py35 testing
  - Replace git.openstack.org URLs with opendev.org URLs
  - eventletutils: Optimise EventletEvent.clear()
  - OpenDev Migration Patch
  - Update master for stable/stein
  - Mask encryption_key_id
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.40.3
  - Update mailinglist from dev to discuss
  - Fix docstring formatting nit in uuidsentinel
  - Fix race condition in eventletutils Event
  - Use template for lower-constraints
  - Remove extra copy.deepcopy
  - Fix exception raise at rpdb session
  - Expose eventlet Event wrapper class
  - add lib-forward-testing-python3 test job
  - add python 3.7 unit test job
  - Remove moxstubout usage
  - Avoid calling eventlet.event.Event.reset()
  - Avoid double-setting event
  - Update reno for stable/rocky
  - Support non-dict mappings in mask_dict_password
  - Clean up .gitignore references to personal tools
  - Update hacking version
  - UUID sentinel
  - add python 3.6 unit test job
  - Don't use monotonic on Python >=3.3
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.36.4
  - Update reno for stable/queens
  - Switch to stestr
  - Imported Translations from Zanata
  - Add release notes link to README
  - Replace 'assertFalse(a in b)' with 'assertNotIn(a, b)'
  - Fix breaking unit tests due to iso8601 changes
  - Capitalize Oslo
  - Add private_key to the list of sanitized keys
  - Fix exception with secretutils
  - Clean imports in code
  - Remove stale pip-missing-reqs tox test
  - Update links in README
  - Add bindep.txt file to prevent fallback to generic list
  - Trivial: Update pypi url to new url
  - Add -W for document build
  - Handle non-string keys appropriately
  - eventletutils: Fix behavior discrepency when reusing Events
  - Clean old output before new doc builds
  - Document specs_matcher.py functions
  - set default python to python3
  - fix tox python3 overrides
  - Fix project name in user docs
  - Remove sphinx settings from setup.cfg
  - Updated from global requirements
  - add lower-constraints job
- remove 0001-Fix-breaking-unit-tests-due-to-iso8601-changes.patch (upstream)
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Feb 13 2018 dmueller@suse.com
- add 0001-Fix-breaking-unit-tests-due-to-iso8601-changes.patch
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 3.35.0
  - Add a mixed mode parser to string_to_bytes
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.34.0
  - Follow the new PTI for document build
  - Add method validate_integer
  - improve docstring for last_bytes()
  - Add method to escape ipv6 ip addresses
  - Add missing information in docstring of validate_integer
  - Add method last_bytes in fileutils
  - Cleanup test-requirements
  - Updated from global requirements
* Wed Dec 13 2017 cloud-devel@suse.de
- update to version 3.32.0
  - Fix some reST field lists in docstrings
  - Remove setting of version/release from releasenotes
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Fri Nov 24 2017 cloud-devel@suse.de
- update to version 3.31.0
  - Update reno for stable/pike
  - Imported Translations from Zanata
  - Prevent deprecation error messages from pkg_resources
  - Add method to compute a file's checksum to fileutils
  - Use six.binary_type to point to the right type
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.28.0
  - rearrange existing documentation to fit the new standard layout
  - Remove log translations
  - Allow scoped ipv6 addresses
  - Add missing documentation for secretutils
  - [Fix gate]Update test requirement
  - switch from oslosphinx to openstackdocstheme
  - Update reno for stable/ocata
  - Remove split conversion to tuple
  - Adding a check of string type for hmacs
  - Update URLs in documents according to document migration
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 3.22.0:
  - Make method import_versioned_module work
  - Add option to not truncate built-ins
  - Add method is_valid_ipv6_cidr
  - Add method is_valid_mac
  - Show team and repo badges on README
  - Extend specs matcher to support ">" and "<"
  - Added the token 'encrypted_key' to mask_password list
  - doc: Fix docstring of method bool_from_string
  - Remove discover from test-requirements
  - Remove references to Python 3.4
  - Change assertTrue(isinstance()) by optimal assert
  - Add __ne__ built-in function
  - Restore <all-in> operator
  - [TrivialFix] Replace 'assertEqual(None, ...)' with 'assertIsNone(...)'
  - Trivial fixes to the usage doc
  - Update homepage with developer documentation page
  - Add missing specs_matcher documentation
  - Allow 'get_all_class_names' to pass kwargs
  - Improve eventlet check when selecting Event backend
  - Add reno for release notes management
  - Add Constraints support
  - Add method is_valid_boolstr
  - Add threading<->eventlet compatible Event
  - Add utils for validating and splitting quotes
  - Create dictutils and add 'flatten_dict_to_keypairs'
  - Add toggle 'dashed' to 'generate_uuid' function
  - Updated from global requirements
* Wed Oct  5 2016 tbechtold@suse.com
- Adjust Requires and BuildRequires
* Fri Jul 29 2016 dmueller@suse.com
- update to 3.16.0:
  * Fix mask_dict_password for non string/dict type key in dict
  * More unit tests for specs matcher
  * Imported Translations from Zanata
  * Add Python 3.5 classifier and venv
  * Use an actual well defined parser for spec matching
  * Remove unused LOG to keep code clean
  * Updated from global requirements
* Mon Jul 11 2016 tbechtold@suse.com
- update 3.15.0:
  * Add basic docstrings to stopwatch has_started/stopped methods
  * Make mask_dict_password consistent with mask_password
  * Updated from global requirements
  * improve tests for mask_password and mask_dict_password
  * Simplify boolean expression in executils.py
* Mon Jul  4 2016 tbechtold@suse.com
- update to 3.14.0:
  * Support json format output from qemu command
  * Fix flake8 issues
  * Use is_valid_ipv4 in get_ipv6_addr_by_EUI64
  * Imported Translations from Zanata
  * Allow assigning "0" to port
  * Updated from global requirements
  * Fix method split_path's docstring 'versionadded'
  * Updated from global requirements
  * Updated from global requirements
  * Avoid catching generic exception
  * Remove method total_seconds in timeuitls
  * Fix is_valid_cidr raises TypeError
* Fri Jun  3 2016 tbechtold@suse.com
- update to 3.11.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * Move method split_path into oslo.utils
  * Imported Translations from Zanata
  * Updated from global requirements
  * Imported Translations from Zanata
  * Provide single step check if eventlet is monkey_patched
  * Add method is_valid_cidr to netutils
  * Updated from global requirements
  * Updated from global requirements
  * Add importutils.import_any method
  * Add excutils.exception_filter
  * Explicitly exclude tests from bandit scan
  * Add CHAPPASSWORD to list of sanitize keys
  * Enable bandit in gate
  * Updated from global requirements
  * Add method check_string_length
  * Add missing versionchanged for configdrive
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- Switch to .spec from rpm-packaging upstream project
* Wed Feb 17 2016 dmueller@suse.com
- update to 3.6.0:
  * remove bandit.conf
* Thu Feb 11 2016 dmueller@suse.com
- update to 3.5.0:
  * Updated from global requirements
  * Narrow mock for getfilesystemencoding
  * Update translation setup
  * Add excutils.save_and_reraise_exception force_reraise + capture
  * Add encodeutils.to_utf8() function
  * Create secretutils and include 'constant_time_compare' function
  * Fix coverage
  * Add a mechanism to mask passwords in dictionaries
  * Add "configdrive" to the list of keys used by mask_password()
  * fix fnmatch.filter in non-posix system
  * fix fileutils ut code random failure
  * Add missing doc index for imageutils and fnmatch
  * re-implement thread safe fnmatch
  * Fix the bug of can't get the desired image info
* Wed Dec 16 2015 bwiedemann@suse.com
- Update to version 3.2.0
  * Remove Babel from requirements
  * Remove duplicated profiles section from bandit.yaml
  * Allow get_class_name to accept bound method and class method
  * deprecate timeutils.total_seconds()
  * Move imageutils from oslo-incubator to oslo.utils
  * networkutils: drop python 2.6 support
  * Remove python 2.6 classifier
  * Fix wrong bug tracking link
  * Refactor Port number validation
  * Add useful 'time_it' decorator
  2.8.0
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 2.8.0:
  * Fix get_class_name() on Python 3
  * Added ICMP 'type' and 'code' checking capability to 'netutils' module
  * Imported Translations from Zanata
  * comment in write_to_tempfile
  * Use versionadded and versionchanged in doc
  * Write document for each unit of oslo_utils.utils
  * Fix usage of "deprecated" markup in docstrings
  * Just use 'exception_to_unicode' to handle exception to string
  * Add 'secret' to sensitive keys
  * Fix coverage configuration and execution
  * Use a stopwatch in 'forever_retry_uncaught_exceptions'
  * No need for Oslo Incubator Sync
  * Make forever_retry_uncaught_exceptions handle its own failures
  * Ensure stopwatch __enter__, __exit__ are in docs
  * Add some timeutils stop watch examples
  * Imported Translations from Zanata
  * Move 'history' -> release notes section
  * Fix bad acting classes and 'is_bound_method' check
  * Change ignore-errors to ignore_errors
  * If 'bool_from_string' provided a boolean just return it
  * Imported Translations from Zanata
  * only capture the ImportError when importing
  * Add 'token' to list of fields to be santized by mask_password
* Tue Sep 15 2015 tbechtold@suse.com
- update to 2.5.0:
  * Updated from global requirements
  * Imported Translations from Transifex
  * Updated from global requirements
  * Updated from global requirements
* Thu Sep  3 2015 tbechtold@suse.com
- update to 2.4.0:
  * Updated from global requirements
  * Updated from global requirements
  * flake8 - remove unused rules
  * Bump monotonic to 0.3 to remove exception catching on import
  * Provide a common exception caused by base class
  * Imported Translations from Transifex
  * Allow access to reflection 'get_members'
  * Updated from global requirements
  * Imported Translations from Transifex
  * Updated from global requirements
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
- Remove test requirements
- Add -doc package
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Tue Jul 28 2015 tbechtold@suse.com
- update to 2.1.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Adding checking around the monotonic import
  * Updated from global requirements
  * Updated from global requirements
  * Add oslo.config to test requirements
  * Remove oslo namespace package
  * Updated from global requirements
- update Requires according to requirements.txt
- remove 0001-Disable-deprecation-warning.patch
* Mon Jul 20 2015 dmueller@suse.com
- fix requires
* Fri Jul 17 2015 dmueller@suse.com
- update to 1.9.0:
  * Updated from global requirements
  * Imported Translations from Transifex
  * Add write_to_tempfile back to fileutils
  * Use monotonic library to avoid finding monotonic time function
  * Fix exception_to_unicode() for oslo_i18n Message
  * Add fileutils to oslo_utils
  * Updated from global requirements
  * Add tox target to find missing requirements
  * Updated from global requirements
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * timeutils: fix newer/older comparison with TZ aware datetime
  * Replace parse_strtime with parse_isotime in older/newer
* Mon Jun  8 2015 tbechtold@suse.com
- update to 1.6.0:
  * Add pytz to requirements
  * Imported Translations from Transifex
  * timeutils: utcnow() can return a value with a timezone
  * Add 'raise_with_cause' chaining helper to excutils
  * timeutils: deprecate isotime()
  * timeutils: make marshall timezone aware
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Updated from global requirements
  * Add exception_to_unicode() function
  * Remove run_cross_tests.sh
  * Imported Translations from Transifex
  * Move versionutils into place and remove deprecation tools
  * Denote monotonic import ordering + usage
  * Add liberty release name to versionutils
  * Expose opts entry point for version_utils
  * Switch from oslo.config to oslo_config
  * Remove oslo.log code and clean up versionutils API
  * Remove code that moved to oslo.i18n
  * Enhance versionutils.deprecated to work with classes
  * Add Kilo release name to versionutils
  * Allow deprecated decorator to specify no plan for removal
  * Uncap library requirements for liberty
  * Add JUNO as a target to versionutils module
  * Add missing reflection + uuidutils docs
  * timeutils: avoid passing leap second to datetime
  * Add pypi download + version badges
  * Cleanup README.rst and setup.cfg
  * pep8: fixed multiple violations
  * Use oslotest instead of common test module
  * Use hacking import_exceptions for gettextutils._
  * fixed typos
  * Fix violations of H302:import only modules
  * Adds decorator to deprecate functions and methods
  * Remove vim header
  * Add `versionutils` for version compatibility checks
  * Update hacking setting
  * Updated from global requirements
  * Imported Translations from Transifex
  * Clean up TestIsIPv6Enabled
  * Fix test_netutils: stop patches
  * Add a new string to the list of masked patterns
  * Provide common `fetch_current_thread_functor` function
  * Imported Translations from Transifex
- Adjust Requires according to requirements.txt
- Add python_requires to _services
* Thu May  7 2015 tbechtold@suse.com
- Add 0001-Disable-deprecation-warning.patch
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.4.0:
  * Add a stopwatch + split for duration(s)
  * Allow providing a logger to save_and_reraise_exception
  * Updated from global requirements
  * Utility API to generate EUI-64 IPv6 address
- update Requires
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 1.3.0:
  * Add a eventlet utils helper module
  * Add microsecond support to iso8601_from_timestamp
  * Updated from global requirements
  * Update Oslo imports to remove namespace package
  * Add TimeFixture
  * Add microsecond support to timeutils.utcnow_ts()
  * Make setup.cfg packages include oslo.utils
- adjust Requires according to requirements.txt
* Wed Jan 14 2015 dmueller@suse.com
- fix requires
* Mon Jan 12 2015 dmueller@suse.com
- update to 1.2.1:
  * Return LOCALHOST if no default interface
  * Improve performance of strutils.mask_password
  * Move files out of the namespace package
  * Add method is_valid_port in netutils
  * Support non-lowercase uuids in is_uuid_like
  * Add 'secret_uuid' in _SANITIZE_KEYS for strutils
  * Imported Translations from Transifex
  * Workflow documentation is now in infra-manual
* Mon Dec 15 2014 dmueller@suse.com
- update to 1.1.0:
  * Add get_my_ip()
  * Updated from global requirements
  * Add 'auth_password' in _SANITIZE_KEYS for strutils
  * Updated from global requirements
  * Activate pep8 check that _ is imported
  * Add uuidutils to oslo.utils
  * Add pbr to installation requirements
  * Updated from global requirements
  * Add is_int_like() function
  * Hide auth_token and new_pass
  * Imported Translations from Transifex
  * Add history/changelog to docs
  * Imported Translations from Transifex
  * Support building wheels (PEP-427)
  * Imported Translations from Transifex
  * Improve docstrings for IP verification functions
  * Imported Translations from Transifex
  * Add ip address validation
  * Fix how it appears we need to use mock_anything to avoid 'self' errors
  * Updated from global requirements
  * Move over a reflection module that taskflow uses
  * Make safe_encode func case-insensitive
  * Enable mask_password to handle byte code strings
  * Updated from global requirements
* Sun Sep 21 2014 tbechtold@suse.com
- Update to version 1.0.0:
  * Version bump
* Thu Sep 11 2014 dmueller@suse.com
- update to 0.3.0:
  * Imported Translations from Transifex
  * Remove unused dependency on oslo.config
  * Updated from global requirements
  * Just use int(BOOL) to convert to 1 or 0
  * Re-enable _import* hidden methods in import_utils
* Tue Aug 26 2014 dmueller@suse.com
- update to 0.2.0:
  * Make strutils.mask_password more secure
  * New public API for mask_password ported from incubator
  * Imported Translations from Transifex
* Wed Aug 13 2014 tbechtold@suse.com
- Initial package for oslo.utils
